.glossary .definitions {
    margin-top: 6rem;
    display: flex;
    flex-direction: column;
    gap: 2rem;
}

.glossary .definitions dd {
    width: 100%;
}

.glossary .definitions div {
    display: flex;
    align-items: center;
}

.glossary .definitions dt {
    width: 10rem;
}
