# Generated by Django 5.2.7 on 2025-10-13 12:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('indicators_lib', '0002_filter_color_indicator_min_mesh_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='indicator',
            name='short_title',
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
    ]
