{% extends "territories_dashboard_lib/website/layout/base.html" %}

{% load static %}

{% block main %}
    <div class="fr-container fr-pt-md-8w fr-pb-md-10w fr-pt-4w fr-pb-6w">
        <h1>Page inconnue</h1>
        <p>Erreur <strong>404</strong></p>
    </div>
{% endblock %}
