# Generated by Django 5.2.7 on 2025-10-28 12:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geo_lib', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='geoelement',
            name='linked_to_indicator',
            field=models.BooleanField(default=False, help_text="Si coché, le filtre de l'indicateur avec le même nom sere relié au filtre de la carte.", verbose_name="Relié aux filtres de l'indicateur"),
        ),
    ]
