# Generated by Django 5.2.3 on 2025-06-30 16:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracking_lib', '0003_cookieinfo'),
    ]

    operations = [
        migrations.AddField(
            model_name='cookieinfo',
            name='ip_address',
            field=models.TextField(blank=True, null=True),
        ),
    ]
