#left-menu[hide] {
    display: none;
}

#sankey-tooltip {
    position: fixed;
    background: rgba(0, 0, 0, 0.8);
    color: white;
    padding: 8px;
    border-radius: 4px;
    pointer-events: none;
    font-size: 12px;
}

.no-data-message {
    display: none;
}

.no-data-message[data-show="true"] {
    display: block;
}
