.side-panel-last-close-button-container {
    display: flex;
    justify-content: end;
    margin-top: 32px;
    margin-right: 4px;
}

.tdbmbd-tabpanel-panel {
    padding-bottom: 64px;
}

.tdbmd-combobox-suggestions li {
    padding: 0.25rem 1rem;
    box-sizing: border-box;
}

.tdbmd-combobox-suggestions li:hover {
    background-color: var(--background-alt-blue-france);
    cursor: pointer;
}
