footer .fr-follow {
    border-top: 1px solid var(--border-default-grey);
}
@media (min-width: 48em) {
    .fr-footer__bottom-item::before {
        margin-right: 0.5rem;
    }
}

.fr-footer__bottom-link {
    white-space: nowrap;
}
