# Generated by Django 5.2.8 on 2025-12-03 13:42

import django.contrib.postgres.fields
import territories_dashboard_lib.website_lib.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('website_lib', '0004_mainconf_description_mainconf_social_image_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='mainconf',
            name='meshes',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.TextField(choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom')]), default=territories_dashboard_lib.website_lib.models.get_default_meshes, help_text="Liste des mailles territoriales activées sur la plateforme, la liste des mailles disponible est : ['fr', 'reg', 'dep', 'epci', 'com', 'aom'].<br/>L'ajout de nouvelles mailles demande une modification de la base de données des indicateurs ainsi que du code.", size=None, verbose_name='Mailles'),
        ),
    ]
