{% load static %}

<!doctype html>
<html lang="fr" data-fr-scheme="light" data-analytics="{% if ANALYTICS_ID %}{{ ANALYTICS_ID|escape }}{% endif %}">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="format-detection" content="telephone=no,date=no,address=no,email=no,url=no">

    <meta name="theme-color" content="#000091">
    <link rel="apple-touch-icon" href="/favicon/apple-touch-icon.png">
    <link rel="icon" href="/favicon/favicon.svg" type="image/svg+xml">
    <link rel="shortcut icon" href="/favicon/favicon.ico" type="image/x-icon">
    <link rel="manifest" href="/favicon/manifest.webmanifest" crossorigin="use-credentials">

    <link rel="stylesheet" href="/dsfr.min.css">
    <link rel="stylesheet" href="/utility/utility.min.css">

    <!-- Script en version es6 module et nomodule pour les navigateurs le ne supportant pas -->
    <script defer type="module" src="/dsfr.module.min.js"></script>
    <script defer type="text/javascript" nomodule src="/dsfr.nomodule.min.js"></script>
    <script> {% include "./base.js" %}</script>

    <title>
      {% block page_title %}{% endblock %}
    </title>

    {% if main_conf.description %}
      <meta name="description" content="{{ main_conf.description }}">
      {% if main_conf.social_image_url %}
          <meta property="og:url" content="{{ absolute_uri }}">
          <meta property="og:type" content="website">
          <meta property="og:title" content="{{ main_conf.title }}">
          <meta property="og:description" content="{{ main_conf.description }}">
          <meta property="og:image" content="{{ main_conf.social_image_url }}">
      {% endif %}
    {% endif %}

    {% if ENVIRONMENT != "prd" %}
      <meta name="robots" content="noindex, nofollow">
    {% endif %}

    <style>
      {% include "territories_dashboard_lib/website/layout/header.css" %}
      {% include "territories_dashboard_lib/website/layout/footer.css" %}
      {% include "territories_dashboard_lib/website/layout/base.css" %}
      {% block css %}{% endblock %}
    </style>

    {% block extra_head %}
    {% endblock %}
  </head>
  <body>
    {% include "./header.html" %}
        {% block main %}
        {% endblock %}
    {% include "./footer.html" %}
  </body>
</html>
