# Generated by Django 5.2.3 on 2025-06-19 14:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('website_lib', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='mainconf',
            name='contact_email',
            field=models.TextField(blank=True, default=None, null=True, verbose_name='Email de contact'),
        ),
        migrations.AddField(
            model_name='mainconf',
            name='newsletter_link',
            field=models.TextField(blank=True, default=None, null=True, verbose_name="Lien d'inscription à la newsletter"),
        ),
        migrations.AddField(
            model_name='mainconf',
            name='show_footer_contact_banner',
            field=models.BooleanField(default=False, help_text="Pour afficher la bannière, l'email de contact et le lien d'inscription à la newsletter doivent être renseignés.", verbose_name='Afficher une bannière de contact au-dessus du footer'),
        ),
    ]
