<div id="tabpanel-{{ key }}-panel" class="fr-tabs__panel tdbmbd-tabpanel-panel {% if selected %}fr-tabs__panel--selected{% endif %}" role="tabpanel" aria-labelledby="tabpanel-{{ key }}" tabindex="0" style="transition: none;">
    <h2>
        {{ title }}
    </h2>
    <div class="fr-input-group autocomplete-input">
        <label id="territories-label-{{ key }}" class="fr-label" for="search-territories-{{ key }}">Sélectionner un territoire</label>
        <div class="fr-input-wrap fr-input-wrap--addon">
            <input
                data-mesh="{{ key }}"
                id="search-territories-{{ key }}" class="fr-input search-territory-input" aria-autocomplete="list" aria-controls="territories-menu-{{ key }}" aria-expanded="false" aria-labelledby="territories-label-{{ key }}" autocomplete="off" role="combobox" type="text"
                ></input>
            <button class="fr-btn fr-icon-arrow-down-s-line autocomplete-btn" aria-controls="territories-menu-{{ key }}" aria-expanded="false" tabindex="-1" title="Sélectionner un territoire">
            </button>
        </div>
    </div>
    <ul id="territories-menu-{{ key }}" data-mesh="{{ key }}" class="tdbmd-combobox-suggestions" role="listbox">
        <li data-type="load"><button onclick="loadMoreTerritories(this)" data-mesh="{{ key }}" class="fr-btn fr-btn--secondary fr-btn--sm">Charger plus de résultats</button></li>
    </ul>
    <input id="selected-territory-id-{{ key }}" type="hidden">
    <input id="selected-territory-mesh-{{ key }}" type="hidden">
    <input id="selected-territory-raw-name-{{ key }}" type="hidden">
    <button
        id="selected-territory-validate-{{ key }}"
        data-mesh="{{ key }}"
        disabled
        class="fr-btn validate-territory-btn"
        onclick="validateTerritory(this)"
    >
        Valider
    </button>
    <em id="selected-territory-name-{{ key }}"></em>
</div>